@@ -54,7 +54,7 @@ class MidiFileSynth:
     def close(self):
         pass
     def join_cmd_and_filename(self, cmd, filename):
-        if cmd.find("%s") != -1:
+        if "%s" in cmd:
             return cmd % filename
         else:
             return " ".join((cmd, filename))
